@@ -1,11 +1,11 @@
-#!/usr/bin/env python
+# Copyright 2022 Touca, Inc. Subject to Apache-2.0 License.
 
-# Copyright 2021 Touca, Inc. Subject to Apache-2.0 License.
-
-from ._types import IntegerType, VectorType, ToucaType
 from datetime import datetime, timedelta
 from enum import Enum
 from typing import Dict, Tuple
+from pathlib import Path
+
+from touca._types import IntegerType, ToucaType, VectorType, BlobType
 
 
 class ResultCategory(Enum):
@@ -39,8 +39,9 @@ class Case:
     """ """
 
     def __init__(self, **kwargs):
-        """ """
+
         self._meta = kwargs
+        self._artifacts: Dict[str, Path] = dict()
         self._results: Dict[str, ResultEntry] = dict()
         self._tics: Dict[str, datetime] = dict()
         self._tocs: Dict[str, datetime] = dict()
@@ -55,6 +56,9 @@ class Case:
         """
         self._results[key] = ResultEntry(typ=ResultCategory.Check, val=value)
 
+    def check_file(self, key: str, file):
+        self._artifacts[key] = file
+
     def assume(self, key: str, value: ToucaType):
         """
         Logs a given value as an assertion for the declared test case
@@ -203,7 +207,6 @@ class Case:
             self._tocs[key] = datetime.now()
 
     def _metrics(self) -> Tuple[str, ToucaType]:
-        """ """
         for key, tic in self._tics.items():
             if key not in self._tocs:
                 continue
@@ -211,7 +214,6 @@ class Case:
             yield key, IntegerType(int(diff))
 
     def _metadata(self) -> Dict[str, str]:
-        """ """
         return {
             "teamslug": self._meta.get("team") or "unknown",
             "testsuite": self._meta.get("suite") or "unknown",
@@ -221,14 +223,15 @@ class Case:
         }
 
     def json(self):
-        """ """
+        results = [
+            {"key": k, "value": v.val.json()}
+            for k, v in self._results.items()
+            if v.typ is ResultCategory.Check
+        ]
+        results.extend({"key": k, "value": str(v)} for k, v in self._artifacts.items())
         return {
             "metadata": self._metadata(),
-            "results": [
-                {"key": k, "value": v.val.json()}
-                for k, v in self._results.items()
-                if v.typ is ResultCategory.Check
-            ],
+            "results": results,
             "assertions": [
                 {"key": k, "value": v.val.json()}
                 for k, v in self._results.items()
@@ -238,9 +241,8 @@ class Case:
         }
 
     def serialize(self) -> bytearray:
-        """ """
-        from flatbuffers import Builder
         import touca._schema as schema
+        from flatbuffers import Builder
 
         dicts = {
             ResultCategory.Check: schema.ResultType.Check,
@@ -266,6 +268,14 @@ class Case:
             schema.ResultAddValue(builder, fbs_value)
             schema.ResultAddTyp(builder, dicts.get(v.typ))
             result_entries.append(schema.ResultEnd(builder))
+        for k, v in self._artifacts.items():
+            fbs_key = Builder.CreateString(builder, k)
+            fbs_value = BlobType(v).serialize(builder)
+            schema.ResultStart(builder)
+            schema.ResultAddKey(builder, fbs_key)
+            schema.ResultAddValue(builder, fbs_value)
+            schema.ResultAddTyp(builder, schema.ResultType.Check)
+            result_entries.append(schema.ResultEnd(builder))
 
         schema.ResultsStartEntriesVector(builder, len(result_entries))
         for item in reversed(result_entries):
