@@ -1,10 +1,9 @@
-#!/usr/bin/env python
+# Copyright 2022 Touca, Inc. Subject to Apache-2.0 License.
 
-# Copyright 2021 Touca, Inc. Subject to Apache-2.0 License.
-
-from typing import Any, Callable, Dict, List, ValuesView, Type
 from threading import get_ident
-from ._case import Case
+from typing import Any, Callable, Dict, List, Type, ValuesView
+
+from touca._case import Case
 
 
 def casemethod(func):
@@ -35,14 +34,12 @@ class Client:
 
     @classmethod
     def instance(cls):
-        """ """
         if not hasattr(cls, "_instance"):
             cls._instance = cls()
         return cls._instance
 
     def __init__(self):
-        """ """
-        from ._types import TypeHandler
+        from touca._types import TypeHandler
 
         self._cases: Dict[str, Case] = dict()
         self._configured = False
@@ -54,7 +51,6 @@ class Client:
         self._type_handler = TypeHandler()
 
     def _active_testcase_name(self) -> str:
-        """ """
         if not self._configured:
             return None
         if self._options.get("concurrency"):
@@ -62,10 +58,9 @@ class Client:
         return self._threads_cases.get(get_ident())
 
     def _make_transport(self) -> bool:
-        """ """
-        from ._transport import Transport
+        from touca._transport import Transport
 
-        keys = ["api_key", "api_url", "team", "suite", "version"]
+        keys = ["api-key", "api-url", "team", "suite", "version"]
         if self._options.get("offline") is True:
             return False
         if not all(k in self._options for k in keys):
@@ -79,10 +74,10 @@ class Client:
         return True
 
     def _serialize(self, cases: ValuesView[Case]) -> bytearray:
-        """ """
         from sys import version_info
-        from flatbuffers import Builder
+
         import touca._schema as schema
+        from flatbuffers import Builder
 
         builder = Builder(1024)
 
@@ -269,6 +264,21 @@ class Client:
             raise RuntimeError("client not configured to perform this operation")
         return self._transport.get_testcases()
 
+    def get_next_batch(self) -> str:
+        """
+        Queries the Touca server for the next version increment of this suite.
+
+        :raises RuntimeError:
+            when called on the client that is not configured to communicate
+            with the Touca server.
+
+        :return: next version increment of this suite
+        """
+        if not self._transport:
+            raise RuntimeError("client not configured to perform this operation")
+        self._options["version"] = self._transport.get_next_batch()
+        return self._options.get("version")
+
     def declare_testcase(self, name: str):
         """
         Declares name of the test case to which all subsequent results will be
@@ -325,6 +335,10 @@ class Client:
     def check(self, key: str, value: Any):
         return self._type_handler.transform(value)
 
+    @casemethod
+    def check_file(self, key: str, file):
+        return
+
     @casemethod
     def assume(self, key: str, value: Any):
         return self._type_handler.transform(value)
@@ -431,6 +445,12 @@ class Client:
         if not self._transport._token:
             raise RuntimeError("client not authenticated")
         self._transport.post(content=self._serialize(self._cases.values()))
+        for case in self._cases.values():
+            testcase_name = case._metadata().get("testcase")
+            for artifact_name, artifact_file in case._artifacts.items():
+                self._transport.post_artifacts(
+                    testcase_name, artifact_name, artifact_file
+                )
 
     def seal(self):
         """
