@@ -1,13 +1,13 @@
-#!/usr/bin/env python
+# Copyright 2022 Touca, Inc. Subject to Apache-2.0 License.
 
-# Copyright 2021 Touca, Inc. Subject to Apache-2.0 License.
-
-from json import dumps
 from abc import ABC, abstractmethod
 from collections.abc import Iterable
-from flatbuffers import Builder
+from json import dumps
+from pathlib import Path
 from typing import Any, Callable, Dict, Type
+
 import touca._schema as schema
+from flatbuffers import Builder
 
 
 class ToucaType(ABC):
@@ -20,6 +20,31 @@ class ToucaType(ABC):
         pass
 
 
+class BlobType(ToucaType):
+    def __init__(self, value: Path):
+        """
+        Converts a given value of type ``Path`` to a BlobType with
+        known serialization into JSON and Binary.
+        """
+        self._value = value
+
+    def json(self):
+        return str(self._value)
+
+    def serialize(self, builder: Builder):
+        from hashlib import sha256
+
+        hash = sha256(self._value.read_bytes()).hexdigest()
+        content = Builder.CreateString(builder, hash)
+        schema.BlobStart(builder)
+        schema.BlobAddValue(builder, content)
+        value = schema.BlobEnd(builder)
+        schema.TypeWrapperStart(builder)
+        schema.TypeWrapperAddValue(builder, value)
+        schema.TypeWrapperAddValueType(builder, schema.Type.Blob)
+        return schema.TypeWrapperEnd(builder)
+
+
 class BoolType(ToucaType):
     def __init__(self, value: bool):
         """
@@ -43,7 +68,7 @@ class BoolType(ToucaType):
 
 class DecimalType(ToucaType):
     def __init__(self, value: float):
-        """ """
+
         self._value = value
 
     def json(self):
@@ -61,7 +86,7 @@ class DecimalType(ToucaType):
 
 class IntegerType(ToucaType):
     def __init__(self, value: int):
-        """ """
+
         self._value = value
 
     def json(self):
@@ -79,7 +104,6 @@ class IntegerType(ToucaType):
 
 class StringType(ToucaType):
     def __init__(self, value: str):
-        """ """
         self._value = value
 
     def json(self):
@@ -98,7 +122,6 @@ class StringType(ToucaType):
 
 class VectorType(ToucaType):
     def __init__(self):
-        """ """
         self._values = []
 
     def add(self, value: ToucaType):
@@ -124,7 +147,6 @@ class VectorType(ToucaType):
 
 class ObjectType(ToucaType):
     def __init__(self, key: str):
-        """ """
         self._name = key
         self._values = {}
 
@@ -160,7 +182,6 @@ class ObjectType(ToucaType):
 
 class TypeHandler:
     def __init__(self):
-        """ """
         from datetime import date
 
         self._primitives: Dict[Type, Callable[[Any], ToucaType]] = {
